@@ -1,9 +1,10 @@
 from sqlalchemy.engine import Engine
-from sqlalchemy.orm.session import SessionTransaction
-from sqlmodel import Session, SQLModel, create_engine
+from sqlmodel import SQLModel, create_engine
 
 from fastack import Fastack
 
+from .session import Session
+
 
 class DatabaseState:
     def __init__(self, engine: Engine):
@@ -13,10 +14,6 @@ class DatabaseState:
         engine = engine or self.engine
         return Session(self.engine, **kwds)
 
-    def atomic(self, engine: Engine = None, **kwds) -> SessionTransaction:
-        engine = engine or self.engine
-        return self.open(engine, **kwds).begin()
-
 
 def setup(app: Fastack):
     @app.on_event("startup")
