@@ -2,8 +2,10 @@ from datetime import datetime
 from typing import Optional
 
 from sqlalchemy import Column, DateTime
-from sqlalchemy.orm.session import SessionTransaction
-from sqlmodel import Field, Session, SQLModel
+from sqlmodel import Field, SQLModel
+
+from . import helpers
+from .session import Session
 
 
 class Model(SQLModel):
@@ -19,37 +21,18 @@ class Model(SQLModel):
         }
 
     @classmethod
-    def create(cls, session: Session, **data) -> "Model":
-        instance = cls(**data)
+    def create(cls: "Model", session: Session, **data) -> "Model":
+        instance: Model = cls(**data)
         instance.save(session)
         return instance
 
     def save(self, session: Session, refresh: bool = True) -> "Model":
-        session.add(self)
-        self._do_commit(session)
-        if refresh and not self._is_atomic_transaction(session):
-            session.refresh(self)
-
+        helpers.db_add(session, self, refresh)
         return self
 
     def update(self, session: Session, **data) -> "Model":
-        for k, v in data.items():
-            setattr(self, k, v)
-
-        self.save(session)
+        helpers.db_update(session, self, **data)
         return self
 
     def delete(self, session: Session) -> None:
-        session.delete(self)
-        self._do_commit(session)
-
-    def _is_atomic_transaction(self, session: Session) -> bool:
-        return session._transaction is not None and isinstance(
-            session._transaction, SessionTransaction
-        )
-
-    def _do_commit(self, session: Session):
-        if self._is_atomic_transaction(session):
-            return
-
-        session.commit()
+        helpers.db_delete(session, self)
